# EmploymentSummary

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDate**](CreatedDate.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDate**](LastModifiedDate.md) |  | [optional] 
**source** | [**Source**](Source.md) |  | [optional] 
**department_name** | **str** |  | [optional] 
**role_title** | **str** |  | [optional] 
**start_date** | [**FuzzyDate**](FuzzyDate.md) |  | [optional] 
**end_date** | [**FuzzyDate**](FuzzyDate.md) |  | [optional] 
**organization** | [**Organization**](Organization.md) |  | [optional] 
**visibility** | **str** |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


